window.Gleam.initSearch([{"doc":"themis","title":"themis","content":"# Themis\n\nPrometheus client in pure Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/themis)](https://hex.pm/packages/themis)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/themis/)\n\n```sh\ngleam add themis\n```\n\n## Quick Start\n\n```gleam\nimport gleam/dict\nimport gleam/io\nimport gleam/set\nimport themis\nimport themis/counter\nimport themis/gauge\nimport themis/histogram\nimport themis/number\n\npub fn main() {\n  // Create the new metrics store\n  let metrics_store = themis.new()\n\n  // Gauge\n\n  // This can fail if the metric name is invalid\n  let assert Ok(metrics_store) =\n    gauge.register(\n      metrics_store,\n      &quot;my_first_metric&quot;,\n      &quot;A gauge Prometheus metric&quot;,\n    )\n\n  let labels = dict.from_list([#(&quot;foo&quot;, &quot;bar&quot;)])\n  let value = number.int(10)\n  let assert Ok(metrics_store) =\n    gauge.observe(metrics_store, &quot;my_first_metric&quot;, labels, value)\n\n  // Counter\n\n  let assert Ok(metrics_store) =\n    counter.register(\n      metrics_store,\n      &quot;my_second_metric&quot;,\n      &quot;A counter Prometheus metric&quot;,\n    )\n\n  let labels = dict.from_list([#(&quot;wibble&quot;, &quot;wobble&quot;)])\n  let other_labels = dict.from_list([#(&quot;wii&quot;, &quot;woo&quot;)])\n  // Counters can optionally be initialized manually\n  let assert Ok(metrics_store) =\n    counter.init_record(metrics_store, &quot;my_second_metric&quot;, labels)\n  let assert Ok(metrics_store) =\n    counter.increment(metrics_store, &quot;my_second_metric&quot;, labels)\n  // When incrementing a counter with new labels, a new counter will automatically be initialized then incremented\n  let assert Ok(metrics_store) =\n    counter.increment_by(\n      metrics_store,\n      &quot;my_second_metric&quot;,\n      other_labels,\n      number.dec(1.2),\n    )\n\n  // Histogram\n\n  // Histograms work with buckets. Each bucket needs an upper boundary.\n  let buckets =\n    set.from_list([\n      number.dec(0.05),\n      number.dec(0.1),\n      number.dec(0.25),\n      number.dec(0.5),\n      number.int(1),\n    ])\n  let assert Ok(metrics_store) =\n    histogram.register(\n      metrics_store,\n      &quot;my_third_metric&quot;,\n      &quot;A histogram Prometheus metric&quot;,\n      buckets,\n    )\n\n  let value = number.int(20)\n  let other_value = number.dec(1.5)\n  let labels = dict.from_list([#(&quot;toto&quot;, &quot;tata&quot;)])\n  let other_labels = dict.from_list([#(&quot;toto&quot;, &quot;titi&quot;)])\n  // Histograms can optionally be initialized manually\n  let assert Ok(metrics_store) =\n    histogram.observe(metrics_store, &quot;my_third_metric&quot;, labels, value)\n  // When incrementing a histogram with new labels, a new histogram will automatically be initialized\n  let assert Ok(metrics_store) =\n    histogram.observe(\n      metrics_store,\n      &quot;my_third_metric&quot;,\n      other_labels,\n      other_value,\n    )\n\n  // Printing all the metrics as a Prometheus-scrapable String\n  themis.print(metrics_store)\n  |&gt; io.println\n}\n\n```\n\nThis code will print the following prometheus-compatible metrics:\n\n```\n# HELP my_first_metric A gauge Prometheus metric\n# TYPE my_first_metric gauge\nmy_first_metric{foo=&quot;bar&quot;} 10\n\n# HELP my_second_metric_total A counter Prometheus metric\n# TYPE my_second_metric_total counter\nmy_second_metric_total{wibble=&quot;wobble&quot;} 1\nmy_second_metric_total{wii=&quot;woo&quot;} 1.2\n\n# HELP my_third_metric A histogram Prometheus metric\n# TYPE my_third_metric histogram\nmy_third_metric_bucket{le=&quot;0.05&quot;,toto=&quot;tata&quot;} 0\nmy_third_metric_bucket{le=&quot;0.1&quot;,toto=&quot;tata&quot;} 0\nmy_third_metric_bucket{le=&quot;0.25&quot;,toto=&quot;tata&quot;} 0\nmy_third_metric_bucket{le=&quot;0.5&quot;,toto=&quot;tata&quot;} 0\nmy_third_metric_bucket{le=&quot;1&quot;,toto=&quot;tata&quot;} 0\nmy_third_metric_bucket{le=&quot;+Inf&quot;,toto=&quot;tata&quot;} 1\nmy_third_metric_sum{toto=&quot;tata&quot;} 1\nmy_third_metric_count{toto=&quot;tata&quot;} 1\n\nmy_third_metric_bucket{le=&quot;0.05&quot;,toto=&quot;titi&quot;} 0\nmy_third_metric_bucket{le=&quot;0.1&quot;,toto=&quot;titi&quot;} 0\nmy_third_metric_bucket{le=&quot;0.25&quot;,toto=&quot;titi&quot;} 0\nmy_third_metric_bucket{le=&quot;0.5&quot;,toto=&quot;titi&quot;} 0\nmy_third_metric_bucket{le=&quot;1&quot;,toto=&quot;titi&quot;} 0\nmy_third_metric_bucket{le=&quot;+Inf&quot;,toto=&quot;titi&quot;} 1\nmy_third_metric_sum{toto=&quot;titi&quot;} 1\nmy_third_metric_count{toto=&quot;titi&quot;} 1\n\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/themis&gt;.\n\n## Usage\n\n### Working with Different Numeric Types\n\nThemis metric values are set using the dedicated `Number` type. There are 5 number types available:\n\n```gleam\nimport themis/number\n\n// Integer values\nlet integer = number.int(1_234_567)\n\n// Decimal (float) values\nlet decimal = number.dec(23.5)\n\n// Special values\nlet positive_infinity = number.pos_inf()\nlet negative_infinity = themis.neg_inf()\nlet not_a_number = themis.nan()\n```\n### Metric Types\n\n#### Gauges\n\nGauges are metrics that represent a single numerical value that can arbitrarily go up and down. They are typically used for measured values like temperatures, current memory usage, or number of active connections.\n\n```gleam\nimport themis/gauge\n\n// Register a new gauge metric\nlet assert Ok(metrics_store) = \n  gauge.register(\n    metrics_store,\n    &quot;process_memory_bytes&quot;,\n    &quot;Current memory usage in bytes&quot;,\n  )\n\n// Set a gauge value with labels\nlet labels = dict.from_list([#(&quot;process&quot;, &quot;web_server&quot;)])\nlet value = number.int(52_428_800)  // 50MB in bytes\nlet assert Ok(metrics_store) =\n  gauge.observe(metrics_store, &quot;process_memory_bytes&quot;, labels, value)\n```\n\n#### Counters\n\nCounters are cumulative metrics that can only increase or be reset to zero. They are typically used to count requests served, tasks completed, errors occurred, or other countable occurrences.\n\n```gleam\nimport themis/counter\n\n// Register a new counter metric\nlet assert Ok(metrics_store) =\n  counter.register(\n    metrics_store,\n    &quot;http_requests_total&quot;,\n    &quot;Total number of HTTP requests made&quot;,\n  )\n\n// Initialize a counter with specific labels (optional)\nlet labels = dict.from_list([#(&quot;method&quot;, &quot;GET&quot;), #(&quot;path&quot;, &quot;/api/users&quot;)])\nlet assert Ok(metrics_store) =\n  counter.init_record(metrics_store, &quot;http_requests_total&quot;, labels)\n\n// Increment counter by 1\nlet assert Ok(metrics_store) =\n  counter.increment(metrics_store, &quot;http_requests_total&quot;, labels)\n\n// Increment counter by specific amount\nlet assert Ok(metrics_store) =\n  counter.increment_by(\n    metrics_store,\n    &quot;http_requests_total&quot;,\n    labels,\n    number.dec(5.0),\n  )\n```\n\n#### Histograms\n\nHistograms sample observations (usually duration or response size) and count them in configurable buckets. They also provide a sum of all observed values and a count of observations.\n\n```gleam\nimport themis/histogram\n\n// Define histogram buckets (upper bounds of observation buckets in seconds)\nlet buckets =\n  set.from_list([\n    number.dec(0.005),  // 5ms\n    number.dec(0.01),   // 10ms\n    number.dec(0.025),  // 25ms\n    number.dec(0.05),   // 50ms\n    number.dec(0.1),    // 100ms\n    number.dec(0.25),   // 250ms\n    number.dec(0.5),    // 500ms\n    number.dec(1.0),    // 1s\n  ])\n\n// Register a new histogram metric\nlet assert Ok(metrics_store) =\n  histogram.register(\n    metrics_store,\n    &quot;http_request_duration_seconds&quot;,\n    &quot;HTTP request duration in seconds&quot;,\n    buckets,\n  )\n\n// Record an observation\nlet labels = dict.from_list([#(&quot;method&quot;, &quot;POST&quot;), #(&quot;path&quot;, &quot;/api/users&quot;)])\nlet duration = number.dec(0.157)  // 157ms\nlet assert Ok(metrics_store) =\n  histogram.observe(\n    metrics_store,\n    &quot;http_request_duration_seconds&quot;,\n    labels,\n    duration,\n  )\n```\n\nEach histogram observation is counted in all buckets with upper bounds greater than the observation value. The `+Inf` bucket is automatically added and counts all observations. Additionally, histograms track the sum of all observed values and the total count of observations.\n\n#### Summaries\n\nSummaries have not yet been implemented, because at first glance it seems an accurate summary must keep a complete history of all the observed values, which will be a huge memory hog. This means I would have to implement some algorithm that goes way above my head to instead derive an approximation. I ain&#39;t doin&#39; that (maybe one day if I need summaries but don&#39;t hold your breath).&lt;br&gt;\nIf you&#39;re feeling adventurous, feel free to open a PR.\n\n## License\n\nMIT","url":"index.html"},{"doc":"themis/number","title":"ComparisonError","content":"pub type ComparisonError {\n  NaNValue\n}\n\nNaNValue\n\n\nSynonyms:\nthemis/number.ComparisonError\nthemis/number ComparisonError","url":"themis/number.html#ComparisonError"},{"doc":"themis/number","title":"Number","content":"pub type Number {\n  PosInf\n  NegInf\n  NaN\n  Dec(Float)\n  Int(Int)\n}\n Prometheus numbers.\n Helpful for displaying and adding/comparing values\n of different types.\nPosInf\n\n\nNegInf\n\n\nNaN\n\n\nDec(Float)\n\n\nInt(Int)\n\n\nSynonyms:\nthemis/number.Number\nthemis/number Number","url":"themis/number.html#Number"},{"doc":"themis/number","title":"add","content":"pub fn add(value1 val1: Number, value2 val2: Number) -&gt; Number\n Add two numbers.\n Any `NaN` input value will always return `NaN`.\n `PosInf` + `NegInf` = `NaN`\nSynonyms:\nthemis/number.add\nthemis/number add","url":"themis/number.html#add"},{"doc":"themis/number","title":"compare","content":"pub fn compare(\n  compare val1: Number,\n  to val2: Number,\n) -&gt; Result(Order, ComparisonError)\n Compare two numbers (see gleam_stdlib/order)\n Will return an error if either value is NaN\nSynonyms:\nthemis/number.compare\nthemis/number compare","url":"themis/number.html#compare"},{"doc":"themis/number","title":"dec","content":"pub fn dec(value value: Float) -&gt; Number\n Creates a Number representing a decimal value.\nSynonyms:\nthemis/number.dec\nthemis/number dec","url":"themis/number.html#dec"},{"doc":"themis/number","title":"int","content":"pub fn int(value value: Int) -&gt; Number\n Creates a Number representing an integer value.\nSynonyms:\nthemis/number.int\nthemis/number int","url":"themis/number.html#int"},{"doc":"themis/number","title":"nan","content":"pub fn nan() -&gt; Number\n Creates a Number representing NaN (Not a Number).\nSynonyms:\nthemis/number.nan\nthemis/number nan","url":"themis/number.html#nan"},{"doc":"themis/number","title":"neg_inf","content":"pub fn neg_inf() -&gt; Number\n Creates a Number representing negative infinity.\nSynonyms:\nthemis/number.neg_inf\nthemis/number neg_inf","url":"themis/number.html#neg_inf"},{"doc":"themis/number","title":"pos_inf","content":"pub fn pos_inf() -&gt; Number\n Creates a Number representing positive infinity.\nSynonyms:\nthemis/number.pos_inf\nthemis/number pos_inf","url":"themis/number.html#pos_inf"},{"doc":"themis/number","title":"print","content":"pub fn print(number: Number) -&gt; String\n Prometheus-scrapable representation of a number\nSynonyms:\nthemis/number.print\nthemis/number print","url":"themis/number.html#print"},{"doc":"themis/number","title":"themis/number","content":"","url":"themis/number.html"},{"doc":"themis","title":"Store","content":"pub type Store {\n  Store(\n    gauges: Dict(metric.MetricName, Metric(Gauge, Number, Nil)),\n    counters: Dict(\n      metric.MetricName,\n      Metric(Counter, Number, Nil),\n    ),\n    histograms: Dict(\n      metric.MetricName,\n      Metric(Histogram, HistogramRecord, Set(Number)),\n    ),\n  )\n}\n A Store manages a collection of metrics, ensuring unique metric names.\nStore(\n  gauges: Dict(metric.MetricName, Metric(Gauge, Number, Nil)),\n  counters: Dict(metric.MetricName, Metric(Counter, Number, Nil)),\n  histograms: Dict(\n    metric.MetricName,\n    Metric(Histogram, HistogramRecord, Set(Number)),\n  ),\n)\n\n\nSynonyms:\nthemis.Store\nthemis Store","url":"themis.html#Store"},{"doc":"themis","title":"StoreError","content":"pub type StoreError {\n  MetricNameAlreadyInUse\n  MetricNameNotFound\n  MetricError(metric.MetricError)\n  LabelError(label.LabelError)\n  CounterError(counter.CounterError)\n  HistogramError(histogram.HistogramError)\n}\n Represents possible errors that can occur when operating on the Store.\nMetricNameAlreadyInUse\n Returned when attempting to create a metric with a name that&#39;s already in use\n\nMetricNameNotFound\n Returned when attempting to operate on a metric that doesn&#39;t exist\n\nMetricError(metric.MetricError)\n Wraps errors related to metric name validation\n\nLabelError(label.LabelError)\n Wraps errors related to label validation\n\nCounterError(counter.CounterError)\n Wraps errors related to counters\n\nHistogramError(histogram.HistogramError)\n Wraps errors related to counters\n\nSynonyms:\nthemis.StoreError\nthemis StoreError","url":"themis.html#StoreError"},{"doc":"themis","title":"is_metric_name_used","content":"pub fn is_metric_name_used(\n  store: Store,\n  name: MetricName,\n) -&gt; Bool\n\nSynonyms:\nthemis.is_metric_name_used\nthemis is_metric_name_used","url":"themis.html#is_metric_name_used"},{"doc":"themis","title":"new","content":"pub fn new() -&gt; Store\n Creates a new empty metrics store.\nSynonyms:\nthemis.new\nthemis new","url":"themis.html#new"},{"doc":"themis","title":"print","content":"pub fn print(metrics_store store: Store) -&gt; String\n Formats all metrics in the store as a Prometheus-compatible text string.\n\n ## Examples\n\n \n let metrics_text = print(store)\n // # HELP my_metric My first gauge\n // # TYPE my_metric gauge\n // my_metric{foo=&quot;bar&quot;} 10\n // my_metric{toto=&quot;tata&quot;,wibble=&quot;wobble&quot;} +Inf\n \nSynonyms:\nthemis.print\nthemis print","url":"themis.html#print"},{"doc":"themis","title":"themis","content":"","url":"themis.html"},{"doc":"themis/counter","title":"increment","content":"pub fn increment(\n  store store: Store,\n  counter_name name_string: String,\n  labels labels_dict: Dict(String, String),\n) -&gt; Result(Store, StoreError)\n Increments a counter record with the given labels by 1.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter\n - `labels`: A dictionary of labels\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = increment(\n   store,\n   &quot;http_request_failures&quot;,\n   labels,\n )\n \nSynonyms:\nthemis/counter.increment\nthemis/counter increment","url":"themis/counter.html#increment"},{"doc":"themis/counter","title":"increment_by","content":"pub fn increment_by(\n  store store: Store,\n  counter_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  by by: Number,\n) -&gt; Result(Store, StoreError)\n Increments a counter record with the given labels by a specified value.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter\n - `labels`: A dictionary of labels\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = increment(\n   store,\n   &quot;http_request_failures&quot;,\n   labels,\n   number.int(12),\n )\n \nSynonyms:\nthemis/counter.increment_by\nthemis/counter increment_by","url":"themis/counter.html#increment_by"},{"doc":"themis/counter","title":"init_record","content":"pub fn init_record(\n  store store: Store,\n  counter_name name_string: String,\n  labels labels_dict: Dict(String, String),\n) -&gt; Result(Store, StoreError)\n Initializes a new counter metric record with the given labels.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter\n - `labels`: A dictionary of labels\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = init_record(\n   store,\n   &quot;http_request_failures&quot;,\n   labels,\n )\n \nSynonyms:\nthemis/counter.init_record\nthemis/counter init_record","url":"themis/counter.html#init_record"},{"doc":"themis/counter","title":"register","content":"pub fn register(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n) -&gt; Result(Store, StoreError)\n Registers a new counter metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the counter to\n - `name`: The name of the new counter metric (must be a valid Prometheus metric name)\n - `description`: A human-readable description of what the counter observes\n\n ## Examples\n\n \n let assert Ok(store) = register(\n   store,\n   &quot;http_request_failures&quot;,\n   &quot;Count of HTTP request failures&quot;,\n )\n \nSynonyms:\nthemis/counter.register\nthemis/counter register","url":"themis/counter.html#register"},{"doc":"themis/counter","title":"unregister","content":"pub fn unregister(\n  store store: Store,\n  counter_name name_string: String,\n) -&gt; Result(Store, StoreError)\n Removes a counter metric and all its recorded values from the store.\n\n ## Arguments\n\n - `store`: The metrics store containing the counter\n - `counter_name`: The name of the counter to delete\n\n ## Examples\n\n \n let assert Ok(store) = unregister(store, &quot;http_request_failures&quot;)\n \nSynonyms:\nthemis/counter.unregister\nthemis/counter unregister","url":"themis/counter.html#unregister"},{"doc":"themis/counter","title":"themis/counter","content":"","url":"themis/counter.html"},{"doc":"themis/gauge","title":"observe","content":"pub fn observe(\n  store store: Store,\n  gauge_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  value value: Number,\n) -&gt; Result(Store, StoreError)\n Records a value for a gauge metric with the given labels.\n\n ## Arguments\n\n - `store`: The metrics store containing the gauge\n - `gauge_name`: The name of the gauge\n - `labels`: A dictionary of labels\n - `value`: The numeric value to record\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let assert Ok(store) = insert_gauge_record(\n   store,\n   &quot;process_cpu_seconds_total&quot;,\n   labels,\n   int(42),\n )\n \nSynonyms:\nthemis/gauge.observe\nthemis/gauge observe","url":"themis/gauge.html#observe"},{"doc":"themis/gauge","title":"register","content":"pub fn register(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n) -&gt; Result(Store, StoreError)\n Registers a new gauge metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the gauge to\n - `name`: The name of the new gauge metric (must be a valid Prometheus metric name)\n - `description`: A human-readable description of what the gauge observes\n\n ## Examples\n\n \n let assert Ok(store) = register(\n   store,\n   &quot;process_cpu_seconds_total&quot;,\n   &quot;Total user and system CPU time spent in seconds&quot;,\n )\n \nSynonyms:\nthemis/gauge.register\nthemis/gauge register","url":"themis/gauge.html#register"},{"doc":"themis/gauge","title":"unregister","content":"pub fn unregister(\n  store store: Store,\n  gauge_name name_string: String,\n) -&gt; Result(Store, StoreError)\n Removes a gauge metric and all its recorded values from the store.\n\n ## Arguments\n\n - `store`: The metrics store containing the gauge\n - `gauge_name`: The name of the gauge to delete\n\n ## Examples\n\n \n let assert Ok(store) = unregister(store, &quot;process_cpu_seconds_total&quot;)\n \nSynonyms:\nthemis/gauge.unregister\nthemis/gauge unregister","url":"themis/gauge.html#unregister"},{"doc":"themis/gauge","title":"themis/gauge","content":"","url":"themis/gauge.html"},{"doc":"themis/histogram","title":"init_record","content":"pub fn init_record(\n  store store: Store,\n  histogram_name name_string: String,\n  labels labels_dict: Dict(String, String),\n) -&gt; Result(Store, StoreError)\n Initializes a new histogram metric record with the given labels.\n\n ## Arguments\n\n - `store`: The metrics store containing the histogram\n - `histogram_name`: The name of the histogram\n - `labels`: A dictionary of labels\n - `bucket_boundaries`: A set of numbers defining the buckets by their `le` limits\n \n Note that a `+Inf` bucket is always added by default if it isn&#39;t provided.\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let buckets = set.from_list(\n   [\n     number.dec(0.05), \n     number.dec(0.1), \n     number.dec(0.2), \n     number.dec(0.5),\n     number.int(1),\n   ]\n )\n let assert Ok(store) = init_record(\n   store,\n   &quot;app_request_processing_seconds&quot;,\n   labels,\n   buckets,\n )\n \nSynonyms:\nthemis/histogram.init_record\nthemis/histogram init_record","url":"themis/histogram.html#init_record"},{"doc":"themis/histogram","title":"observe","content":"pub fn observe(\n  store store: Store,\n  histogram_name name_string: String,\n  labels labels_dict: Dict(String, String),\n  value value: Number,\n) -&gt; Result(Store, StoreError)\n Records an observation value for a histogram metric.\n\n ## Arguments\n\n - `store`: The metrics store containing the histogram\n - `histogram_name`: The name of the histogram metric\n - `labels`: A dictionary of labels\n - `value`: The value to record in the histogram\n\n ## Examples\n\n \n let labels = dict.from_list([#(&quot;instance&quot;, &quot;localhost:9090&quot;)])\n let value = number.dec(0.123)\n let assert Ok(store) = observe(\n   store,\n   &quot;app_request_processing_seconds&quot;, \n   labels,\n   value,\n )\n \nSynonyms:\nthemis/histogram.observe\nthemis/histogram observe","url":"themis/histogram.html#observe"},{"doc":"themis/histogram","title":"register","content":"pub fn register(\n  store store: Store,\n  name name_string: String,\n  description description: String,\n  buckets buckets: Set(Number),\n) -&gt; Result(Store, StoreError)\n Registers a new histogram metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the histogram to\n - `name`: The name of the new histogram metric (must be a valid Prometheus metric name)\n - `description`: A human-readable description of what the histogram observes\n - `buckets`: A set of numbers defining the buckets by their `le` limits\n\n ## Examples\n\n \n let assert Ok(store) = register(\n   store,\n   &quot;app_request_processing_seconds&quot;,\n   &quot;Time spent processing request&quot;,\n )\n \nSynonyms:\nthemis/histogram.register\nthemis/histogram register","url":"themis/histogram.html#register"},{"doc":"themis/histogram","title":"unregister","content":"pub fn unregister(\n  store store: Store,\n  histogram_name name_string: String,\n) -&gt; Result(Store, StoreError)\n Unregisters a new histogram metric to the store.\n\n ## Arguments\n\n - `store`: The metrics store to add the histogram to\n - `name`: The name of the new histogram metric (must be a valid Prometheus metric name)\n\n ## Examples\n\n \n let assert Ok(store) = unregister(\n   store,\n   &quot;app_request_processing_seconds&quot;,\n )\n \nSynonyms:\nthemis/histogram.unregister\nthemis/histogram unregister","url":"themis/histogram.html#unregister"},{"doc":"themis/histogram","title":"themis/histogram","content":"","url":"themis/histogram.html"}]);